@@ -1,4 +1,5 @@
 {-# LANGUAGE CPP #-}
+{-# LANGUAGE DeriveFunctor #-}
 module Options (
   Result(..)
 , Run(..)
@@ -24,12 +25,13 @@ import           Interpreter (ghc)
 usage :: String
 usage = unlines [
     "Usage:"
-  , "  doctest [ --no-magic | GHC OPTION | MODULE ]..."
+  , "  doctest [ --fast | --no-magic | GHC OPTION | MODULE ]..."
   , "  doctest --help"
   , "  doctest --version"
   , "  doctest --info"
   , ""
   , "Options:"
+  , "  --fast     disable :reload between example groups"
   , "  --help     display this help and exit"
   , "  --version  output version information and exit"
   , "  --info     output machine-readable version information and exit"
@@ -55,8 +57,8 @@ info = "[ " ++ (intercalate "\n, " . map show $ [
   , ("ghc", ghc)
   ]) ++ "\n]\n"
 
-data Result = Output String | Result Run
-  deriving (Eq, Show)
+data Result a = Output String | Result a
+  deriving (Eq, Show, Functor)
 
 type Warning = String
 
@@ -64,20 +66,26 @@ data Run = Run {
   runWarnings :: [Warning]
 , runOptions :: [String]
 , runMagicMode :: Bool
+, runFastMode :: Bool
 } deriving (Eq, Show)
 
-parseOptions :: [String] -> Result
+parseOptions :: [String] -> Result Run
 parseOptions args
   | "--help" `elem` args = Output usage
   | "--info" `elem` args = Output info
   | "--version" `elem` args = Output versionInfo
-  | otherwise = case stripOptGhc <$> stripNoMagic args of
-      (magicMode, (warning, xs)) -> Result (Run (maybeToList warning) xs magicMode)
+  | otherwise = case fmap stripOptGhc . stripFast <$> stripNoMagic args of
+      (magicMode, (fastMode, (warning, xs))) ->
+        Result (Run (maybeToList warning) xs magicMode fastMode)
 
 stripNoMagic :: [String] -> (Bool, [String])
-stripNoMagic args = (noMagic `notElem` args, filter (/= noMagic) args)
-  where
-    noMagic = "--no-magic"
+stripNoMagic = stripFlag False "--no-magic"
+
+stripFast :: [String] -> (Bool, [String])
+stripFast = stripFlag True  "--fast"
+
+stripFlag :: Bool -> String -> [String] -> (Bool, [String])
+stripFlag enableIt flag args = ((flag `elem` args) == enableIt, filter (/= flag) args)
 
 stripOptGhc :: [String] -> (Maybe Warning, [String])
 stripOptGhc = go
