@@ -53,8 +53,10 @@ type Interaction = (Expression, ExpectedResult)
 -- Extract 'DocTest's from all given modules and all modules included by the
 -- given modules.
 getDocTests :: [String] -> IO [Module [Located DocTest]]  -- ^ Extracted 'DocTest's
-getDocTests args = do
-  filter (not . isEmpty) . map parseModule <$> extract args
+getDocTests args = parseModules <$> extract args
+
+parseModules :: [Module (Located String)] -> [Module [Located DocTest]]
+parseModules = filter (not . isEmpty) . map parseModule
   where
     isEmpty (Module _ setup tests) = null tests && isNothing setup
 
